@@ -6,7 +6,7 @@ from tensorfn.util import (
     add_distributed_args,
     load_wandb,
     ensure_tuple,
-    setup_logger,
+    get_logger,
     create_small_table,
 )
 from tensorfn.checker import Checker
